# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from equinix.services.metalv1.models.spot_prices_per_baremetal import SpotPricesPerBaremetal
from typing import Optional, Set
from typing_extensions import Self

class SpotPricesPerFacility(BaseModel):
    """
    SpotPricesPerFacility
    """ # noqa: E501
    baremetal_0: Optional[SpotPricesPerBaremetal] = None
    baremetal_1: Optional[SpotPricesPerBaremetal] = None
    baremetal_2: Optional[SpotPricesPerBaremetal] = None
    baremetal_2a: Optional[SpotPricesPerBaremetal] = None
    baremetal_2a2: Optional[SpotPricesPerBaremetal] = None
    baremetal_3: Optional[SpotPricesPerBaremetal] = None
    baremetal_s: Optional[SpotPricesPerBaremetal] = None
    c2_medium_x86: Optional[SpotPricesPerBaremetal] = Field(default=None, alias="c2.medium.x86")
    href: Optional[StrictStr] = None
    m2_xlarge_x86: Optional[SpotPricesPerBaremetal] = Field(default=None, alias="m2.xlarge.x86")
    __properties: ClassVar[List[str]] = ["baremetal_0", "baremetal_1", "baremetal_2", "baremetal_2a", "baremetal_2a2", "baremetal_3", "baremetal_s", "c2.medium.x86", "href", "m2.xlarge.x86"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of SpotPricesPerFacility from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of baremetal_0
        if self.baremetal_0:
            _dict['baremetal_0'] = self.baremetal_0.to_dict()
        # override the default output from pydantic by calling `to_dict()` of baremetal_1
        if self.baremetal_1:
            _dict['baremetal_1'] = self.baremetal_1.to_dict()
        # override the default output from pydantic by calling `to_dict()` of baremetal_2
        if self.baremetal_2:
            _dict['baremetal_2'] = self.baremetal_2.to_dict()
        # override the default output from pydantic by calling `to_dict()` of baremetal_2a
        if self.baremetal_2a:
            _dict['baremetal_2a'] = self.baremetal_2a.to_dict()
        # override the default output from pydantic by calling `to_dict()` of baremetal_2a2
        if self.baremetal_2a2:
            _dict['baremetal_2a2'] = self.baremetal_2a2.to_dict()
        # override the default output from pydantic by calling `to_dict()` of baremetal_3
        if self.baremetal_3:
            _dict['baremetal_3'] = self.baremetal_3.to_dict()
        # override the default output from pydantic by calling `to_dict()` of baremetal_s
        if self.baremetal_s:
            _dict['baremetal_s'] = self.baremetal_s.to_dict()
        # override the default output from pydantic by calling `to_dict()` of c2_medium_x86
        if self.c2_medium_x86:
            _dict['c2.medium.x86'] = self.c2_medium_x86.to_dict()
        # override the default output from pydantic by calling `to_dict()` of m2_xlarge_x86
        if self.m2_xlarge_x86:
            _dict['m2.xlarge.x86'] = self.m2_xlarge_x86.to_dict()
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of SpotPricesPerFacility from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "baremetal_0": SpotPricesPerBaremetal.from_dict(obj["baremetal_0"]) if obj.get("baremetal_0") is not None else None,
            "baremetal_1": SpotPricesPerBaremetal.from_dict(obj["baremetal_1"]) if obj.get("baremetal_1") is not None else None,
            "baremetal_2": SpotPricesPerBaremetal.from_dict(obj["baremetal_2"]) if obj.get("baremetal_2") is not None else None,
            "baremetal_2a": SpotPricesPerBaremetal.from_dict(obj["baremetal_2a"]) if obj.get("baremetal_2a") is not None else None,
            "baremetal_2a2": SpotPricesPerBaremetal.from_dict(obj["baremetal_2a2"]) if obj.get("baremetal_2a2") is not None else None,
            "baremetal_3": SpotPricesPerBaremetal.from_dict(obj["baremetal_3"]) if obj.get("baremetal_3") is not None else None,
            "baremetal_s": SpotPricesPerBaremetal.from_dict(obj["baremetal_s"]) if obj.get("baremetal_s") is not None else None,
            "c2.medium.x86": SpotPricesPerBaremetal.from_dict(obj["c2.medium.x86"]) if obj.get("c2.medium.x86") is not None else None,
            "href": obj.get("href"),
            "m2.xlarge.x86": SpotPricesPerBaremetal.from_dict(obj["m2.xlarge.x86"]) if obj.get("m2.xlarge.x86") is not None else None
        })
        return _obj





# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.api.licenses_api import LicensesApi


class TestLicensesApi(unittest.TestCase):
    """LicensesApi unit test stubs"""

    def setUp(self) -> None:
        self.api = LicensesApi()

    def tearDown(self) -> None:
        pass

    def test_create_license(self) -> None:
        """Test case for create_license

        Create a License
        """
        pass

    def test_delete_license(self) -> None:
        """Test case for delete_license

        Delete the license
        """
        pass

    def test_find_license_by_id(self) -> None:
        """Test case for find_license_by_id

        Retrieve a license
        """
        pass

    def test_find_project_licenses(self) -> None:
        """Test case for find_project_licenses

        Retrieve all licenses
        """
        pass

    def test_update_license(self) -> None:
        """Test case for update_license

        Update the license
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Equinix Fabric API v4

    Equinix Fabric is an advanced software-defined interconnection solution that enables you to directly, securely and dynamically connect to distributed infrastructure and digital ecosystems on platform Equinix via a single port, Customers can use Fabric to connect to: </br> 1. Cloud Service Providers - Clouds, network and other service providers.  </br> 2. Enterprises - Other Equinix customers, vendors and partners.  </br> 3. Myself - Another customer instance deployed at Equinix. </br> </br> <b>Integrations (SDKs, Tools) links:</b> </br> <a href=\"https://deploy.equinix.com/labs/fabric-java\\\">Fabric Java SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-go\\\">Fabric Go SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-python\\\">Fabric Python SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-provider-equinix\\\">Equinix Terraform Provider</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-equinix-fabric\\\">Fabric Terraform Modules</a> </br> <a href=\"https://deploy.equinix.com/labs/pulumi-provider-equinix/\">Equinix Pulumi Provider</a> </br>

    The version of the OpenAPI document: 4.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501

import warnings
from pydantic import validate_call, Field, StrictFloat, StrictStr, StrictInt
from typing import Any, Dict, List, Optional, Tuple, Union
from typing_extensions import Annotated

from datetime import datetime
from pydantic import Field, StrictInt, StrictStr
from typing import List, Optional
from typing_extensions import Annotated
from equinix.services.fabricv4.models.duration import Duration
from equinix.services.fabricv4.models.metric_interval import MetricInterval
from equinix.services.fabricv4.models.query_direction import QueryDirection
from equinix.services.fabricv4.models.sort import Sort
from equinix.services.fabricv4.models.statistics import Statistics
from equinix.services.fabricv4.models.top_utilized_statistics import TopUtilizedStatistics
from equinix.services.fabricv4.models.view_point import ViewPoint

from equinix.services.fabricv4.api_client import ApiClient, RequestSerialized
from equinix.services.fabricv4.api_response import ApiResponse
from equinix.services.fabricv4.rest import RESTResponseType


class StatisticsApi:
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None) -> None:
        if api_client is None:
            api_client = ApiClient.get_default()
        self.api_client = api_client


    @validate_call
    def get_connection_stats_by_port_uuid(
        self,
        connection_id: Annotated[StrictStr, Field(description="Connection UUID")],
        start_date_time: Annotated[datetime, Field(description="startDateTime")],
        end_date_time: Annotated[datetime, Field(description="endDateTime")],
        view_point: Annotated[ViewPoint, Field(description="viewPoint")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Statistics:
        """Get Stats by uuid

        This API provides service-level metrics so that you can view access and gather key information required to manage service subscription sizing and capacity

        :param connection_id: Connection UUID (required)
        :type connection_id: str
        :param start_date_time: startDateTime (required)
        :type start_date_time: datetime
        :param end_date_time: endDateTime (required)
        :type end_date_time: datetime
        :param view_point: viewPoint (required)
        :type view_point: ViewPoint
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_connection_stats_by_port_uuid_serialize(
            connection_id=connection_id,
            start_date_time=start_date_time,
            end_date_time=end_date_time,
            view_point=view_point,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Statistics",
            '401': "List[Error]",
            '403': "List[Error]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_connection_stats_by_port_uuid_with_http_info(
        self,
        connection_id: Annotated[StrictStr, Field(description="Connection UUID")],
        start_date_time: Annotated[datetime, Field(description="startDateTime")],
        end_date_time: Annotated[datetime, Field(description="endDateTime")],
        view_point: Annotated[ViewPoint, Field(description="viewPoint")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[Statistics]:
        """Get Stats by uuid

        This API provides service-level metrics so that you can view access and gather key information required to manage service subscription sizing and capacity

        :param connection_id: Connection UUID (required)
        :type connection_id: str
        :param start_date_time: startDateTime (required)
        :type start_date_time: datetime
        :param end_date_time: endDateTime (required)
        :type end_date_time: datetime
        :param view_point: viewPoint (required)
        :type view_point: ViewPoint
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_connection_stats_by_port_uuid_serialize(
            connection_id=connection_id,
            start_date_time=start_date_time,
            end_date_time=end_date_time,
            view_point=view_point,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Statistics",
            '401': "List[Error]",
            '403': "List[Error]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_connection_stats_by_port_uuid_without_preload_content(
        self,
        connection_id: Annotated[StrictStr, Field(description="Connection UUID")],
        start_date_time: Annotated[datetime, Field(description="startDateTime")],
        end_date_time: Annotated[datetime, Field(description="endDateTime")],
        view_point: Annotated[ViewPoint, Field(description="viewPoint")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Stats by uuid

        This API provides service-level metrics so that you can view access and gather key information required to manage service subscription sizing and capacity

        :param connection_id: Connection UUID (required)
        :type connection_id: str
        :param start_date_time: startDateTime (required)
        :type start_date_time: datetime
        :param end_date_time: endDateTime (required)
        :type end_date_time: datetime
        :param view_point: viewPoint (required)
        :type view_point: ViewPoint
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_connection_stats_by_port_uuid_serialize(
            connection_id=connection_id,
            start_date_time=start_date_time,
            end_date_time=end_date_time,
            view_point=view_point,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Statistics",
            '401': "List[Error]",
            '403': "List[Error]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_connection_stats_by_port_uuid_serialize(
        self,
        connection_id,
        start_date_time,
        end_date_time,
        view_point,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if connection_id is not None:
            _path_params['connectionId'] = connection_id
        # process the query parameters
        if start_date_time is not None:
            if isinstance(start_date_time, datetime):
                _query_params.append(
                    (
                        'startDateTime',
                        start_date_time.strftime(
                            self.api_client.configuration.datetime_format
                        )
                    )
                )
            else:
                _query_params.append(('startDateTime', start_date_time))
            
        if end_date_time is not None:
            if isinstance(end_date_time, datetime):
                _query_params.append(
                    (
                        'endDateTime',
                        end_date_time.strftime(
                            self.api_client.configuration.datetime_format
                        )
                    )
                )
            else:
                _query_params.append(('endDateTime', end_date_time))
            
        if view_point is not None:
            
            _query_params.append(('viewPoint', view_point.value))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/fabric/v4/connections/{connectionId}/stats',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_port_stats(
        self,
        metros: Annotated[List[StrictStr], Field(description="Two-letter prefix indicating the metropolitan area in which a specified Equinix asset is located.")],
        sort: Annotated[Optional[Sort], Field(description="Key or set of keys that organizes the search payload by property (such as createdDate or metroCode) or by direction. Ascending (ASC) is the default value. The \"?\" prefix indicates descending (DESC) order.")] = None,
        top: Annotated[Optional[StrictInt], Field(description="Filter returning only the specified number of most heavily trafficked ports. The standard value is [1...10], and the default is 5.")] = None,
        duration: Annotated[Optional[Duration], Field(description="duration")] = None,
        direction: Annotated[Optional[QueryDirection], Field(description="Direction of traffic from the requester's viewpoint. The default is outbound.")] = None,
        metric_interval: Annotated[Optional[MetricInterval], Field(description="metricInterval")] = None,
        project_id: Annotated[Optional[StrictStr], Field(description="projectId")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> TopUtilizedStatistics:
        """Top Port Statistics

        This API provides top utilized service-level traffic metrics so that you can view access and gather key information required to manage service subscription sizing and capacity.

        :param metros: Two-letter prefix indicating the metropolitan area in which a specified Equinix asset is located. (required)
        :type metros: List[str]
        :param sort: Key or set of keys that organizes the search payload by property (such as createdDate or metroCode) or by direction. Ascending (ASC) is the default value. The \"?\" prefix indicates descending (DESC) order.
        :type sort: Sort
        :param top: Filter returning only the specified number of most heavily trafficked ports. The standard value is [1...10], and the default is 5.
        :type top: int
        :param duration: duration
        :type duration: Duration
        :param direction: Direction of traffic from the requester's viewpoint. The default is outbound.
        :type direction: QueryDirection
        :param metric_interval: metricInterval
        :type metric_interval: MetricInterval
        :param project_id: projectId
        :type project_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_port_stats_serialize(
            metros=metros,
            sort=sort,
            top=top,
            duration=duration,
            direction=direction,
            metric_interval=metric_interval,
            project_id=project_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TopUtilizedStatistics",
            '401': "List[Error]",
            '403': "List[Error]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_port_stats_with_http_info(
        self,
        metros: Annotated[List[StrictStr], Field(description="Two-letter prefix indicating the metropolitan area in which a specified Equinix asset is located.")],
        sort: Annotated[Optional[Sort], Field(description="Key or set of keys that organizes the search payload by property (such as createdDate or metroCode) or by direction. Ascending (ASC) is the default value. The \"?\" prefix indicates descending (DESC) order.")] = None,
        top: Annotated[Optional[StrictInt], Field(description="Filter returning only the specified number of most heavily trafficked ports. The standard value is [1...10], and the default is 5.")] = None,
        duration: Annotated[Optional[Duration], Field(description="duration")] = None,
        direction: Annotated[Optional[QueryDirection], Field(description="Direction of traffic from the requester's viewpoint. The default is outbound.")] = None,
        metric_interval: Annotated[Optional[MetricInterval], Field(description="metricInterval")] = None,
        project_id: Annotated[Optional[StrictStr], Field(description="projectId")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[TopUtilizedStatistics]:
        """Top Port Statistics

        This API provides top utilized service-level traffic metrics so that you can view access and gather key information required to manage service subscription sizing and capacity.

        :param metros: Two-letter prefix indicating the metropolitan area in which a specified Equinix asset is located. (required)
        :type metros: List[str]
        :param sort: Key or set of keys that organizes the search payload by property (such as createdDate or metroCode) or by direction. Ascending (ASC) is the default value. The \"?\" prefix indicates descending (DESC) order.
        :type sort: Sort
        :param top: Filter returning only the specified number of most heavily trafficked ports. The standard value is [1...10], and the default is 5.
        :type top: int
        :param duration: duration
        :type duration: Duration
        :param direction: Direction of traffic from the requester's viewpoint. The default is outbound.
        :type direction: QueryDirection
        :param metric_interval: metricInterval
        :type metric_interval: MetricInterval
        :param project_id: projectId
        :type project_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_port_stats_serialize(
            metros=metros,
            sort=sort,
            top=top,
            duration=duration,
            direction=direction,
            metric_interval=metric_interval,
            project_id=project_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TopUtilizedStatistics",
            '401': "List[Error]",
            '403': "List[Error]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_port_stats_without_preload_content(
        self,
        metros: Annotated[List[StrictStr], Field(description="Two-letter prefix indicating the metropolitan area in which a specified Equinix asset is located.")],
        sort: Annotated[Optional[Sort], Field(description="Key or set of keys that organizes the search payload by property (such as createdDate or metroCode) or by direction. Ascending (ASC) is the default value. The \"?\" prefix indicates descending (DESC) order.")] = None,
        top: Annotated[Optional[StrictInt], Field(description="Filter returning only the specified number of most heavily trafficked ports. The standard value is [1...10], and the default is 5.")] = None,
        duration: Annotated[Optional[Duration], Field(description="duration")] = None,
        direction: Annotated[Optional[QueryDirection], Field(description="Direction of traffic from the requester's viewpoint. The default is outbound.")] = None,
        metric_interval: Annotated[Optional[MetricInterval], Field(description="metricInterval")] = None,
        project_id: Annotated[Optional[StrictStr], Field(description="projectId")] = None,
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Top Port Statistics

        This API provides top utilized service-level traffic metrics so that you can view access and gather key information required to manage service subscription sizing and capacity.

        :param metros: Two-letter prefix indicating the metropolitan area in which a specified Equinix asset is located. (required)
        :type metros: List[str]
        :param sort: Key or set of keys that organizes the search payload by property (such as createdDate or metroCode) or by direction. Ascending (ASC) is the default value. The \"?\" prefix indicates descending (DESC) order.
        :type sort: Sort
        :param top: Filter returning only the specified number of most heavily trafficked ports. The standard value is [1...10], and the default is 5.
        :type top: int
        :param duration: duration
        :type duration: Duration
        :param direction: Direction of traffic from the requester's viewpoint. The default is outbound.
        :type direction: QueryDirection
        :param metric_interval: metricInterval
        :type metric_interval: MetricInterval
        :param project_id: projectId
        :type project_id: str
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_port_stats_serialize(
            metros=metros,
            sort=sort,
            top=top,
            duration=duration,
            direction=direction,
            metric_interval=metric_interval,
            project_id=project_id,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "TopUtilizedStatistics",
            '401': "List[Error]",
            '403': "List[Error]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_port_stats_serialize(
        self,
        metros,
        sort,
        top,
        duration,
        direction,
        metric_interval,
        project_id,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
            'metros': 'multi',
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        # process the query parameters
        if sort is not None:
            
            _query_params.append(('sort', sort.value))
            
        if top is not None:
            
            _query_params.append(('top', top))
            
        if duration is not None:
            
            _query_params.append(('duration', duration.value))
            
        if direction is not None:
            
            _query_params.append(('direction', direction.value))
            
        if metric_interval is not None:
            
            _query_params.append(('metricInterval', metric_interval.value))
            
        if metros is not None:
            
            _query_params.append(('metros', metros))
            
        if project_id is not None:
            
            _query_params.append(('projectId', project_id))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/fabric/v4/ports/stats',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )




    @validate_call
    def get_port_stats_by_port_uuid(
        self,
        port_id: Annotated[StrictStr, Field(description="Port UUID")],
        start_date_time: Annotated[datetime, Field(description="startDateTime")],
        end_date_time: Annotated[datetime, Field(description="endDateTime")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> Statistics:
        """Get Stats by uuid

        This API provides service-level traffic metrics so that you can view access and gather key information required to manage service subscription sizing and capacity.

        :param port_id: Port UUID (required)
        :type port_id: str
        :param start_date_time: startDateTime (required)
        :type start_date_time: datetime
        :param end_date_time: endDateTime (required)
        :type end_date_time: datetime
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_port_stats_by_port_uuid_serialize(
            port_id=port_id,
            start_date_time=start_date_time,
            end_date_time=end_date_time,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Statistics",
            '401': "List[Error]",
            '403': "List[Error]",
            '500': "List[Error]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        ).data


    @validate_call
    def get_port_stats_by_port_uuid_with_http_info(
        self,
        port_id: Annotated[StrictStr, Field(description="Port UUID")],
        start_date_time: Annotated[datetime, Field(description="startDateTime")],
        end_date_time: Annotated[datetime, Field(description="endDateTime")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> ApiResponse[Statistics]:
        """Get Stats by uuid

        This API provides service-level traffic metrics so that you can view access and gather key information required to manage service subscription sizing and capacity.

        :param port_id: Port UUID (required)
        :type port_id: str
        :param start_date_time: startDateTime (required)
        :type start_date_time: datetime
        :param end_date_time: endDateTime (required)
        :type end_date_time: datetime
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_port_stats_by_port_uuid_serialize(
            port_id=port_id,
            start_date_time=start_date_time,
            end_date_time=end_date_time,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Statistics",
            '401': "List[Error]",
            '403': "List[Error]",
            '500': "List[Error]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        response_data.read()
        return self.api_client.response_deserialize(
            response_data=response_data,
            response_types_map=_response_types_map,
        )


    @validate_call
    def get_port_stats_by_port_uuid_without_preload_content(
        self,
        port_id: Annotated[StrictStr, Field(description="Port UUID")],
        start_date_time: Annotated[datetime, Field(description="startDateTime")],
        end_date_time: Annotated[datetime, Field(description="endDateTime")],
        _request_timeout: Union[
            None,
            Annotated[StrictFloat, Field(gt=0)],
            Tuple[
                Annotated[StrictFloat, Field(gt=0)],
                Annotated[StrictFloat, Field(gt=0)]
            ]
        ] = None,
        _request_auth: Optional[Dict[StrictStr, Any]] = None,
        _content_type: Optional[StrictStr] = None,
        _headers: Optional[Dict[StrictStr, Any]] = None,
        _host_index: Annotated[StrictInt, Field(ge=0, le=0)] = 0,
    ) -> RESTResponseType:
        """Get Stats by uuid

        This API provides service-level traffic metrics so that you can view access and gather key information required to manage service subscription sizing and capacity.

        :param port_id: Port UUID (required)
        :type port_id: str
        :param start_date_time: startDateTime (required)
        :type start_date_time: datetime
        :param end_date_time: endDateTime (required)
        :type end_date_time: datetime
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :type _request_timeout: int, tuple(int, int), optional
        :param _request_auth: set to override the auth_settings for an a single
                              request; this effectively ignores the
                              authentication in the spec for a single request.
        :type _request_auth: dict, optional
        :param _content_type: force content-type for the request.
        :type _content_type: str, Optional
        :param _headers: set to override the headers for a single
                         request; this effectively ignores the headers
                         in the spec for a single request.
        :type _headers: dict, optional
        :param _host_index: set to override the host_index for a single
                            request; this effectively ignores the host_index
                            in the spec for a single request.
        :type _host_index: int, optional
        :return: Returns the result object.
        """ # noqa: E501

        _param = self._get_port_stats_by_port_uuid_serialize(
            port_id=port_id,
            start_date_time=start_date_time,
            end_date_time=end_date_time,
            _request_auth=_request_auth,
            _content_type=_content_type,
            _headers=_headers,
            _host_index=_host_index
        )

        _response_types_map: Dict[str, Optional[str]] = {
            '200': "Statistics",
            '401': "List[Error]",
            '403': "List[Error]",
            '500': "List[Error]",
        }
        response_data = self.api_client.call_api(
            *_param,
            _request_timeout=_request_timeout
        )
        return response_data.response


    def _get_port_stats_by_port_uuid_serialize(
        self,
        port_id,
        start_date_time,
        end_date_time,
        _request_auth,
        _content_type,
        _headers,
        _host_index,
    ) -> RequestSerialized:

        _host = None

        _collection_formats: Dict[str, str] = {
        }

        _path_params: Dict[str, str] = {}
        _query_params: List[Tuple[str, str]] = []
        _header_params: Dict[str, Optional[str]] = _headers or {}
        _form_params: List[Tuple[str, str]] = []
        _files: Dict[str, str] = {}
        _body_params: Optional[bytes] = None

        # process the path parameters
        if port_id is not None:
            _path_params['portId'] = port_id
        # process the query parameters
        if start_date_time is not None:
            if isinstance(start_date_time, datetime):
                _query_params.append(
                    (
                        'startDateTime',
                        start_date_time.strftime(
                            self.api_client.configuration.datetime_format
                        )
                    )
                )
            else:
                _query_params.append(('startDateTime', start_date_time))
            
        if end_date_time is not None:
            if isinstance(end_date_time, datetime):
                _query_params.append(
                    (
                        'endDateTime',
                        end_date_time.strftime(
                            self.api_client.configuration.datetime_format
                        )
                    )
                )
            else:
                _query_params.append(('endDateTime', end_date_time))
            
        # process the header parameters
        # process the form parameters
        # process the body parameter


        # set the HTTP header `Accept`
        _header_params['Accept'] = self.api_client.select_header_accept(
            [
                'application/json'
            ]
        )


        # authentication setting
        _auth_settings: List[str] = [
            'BearerAuth'
        ]

        return self.api_client.param_serialize(
            method='GET',
            resource_path='/fabric/v4/ports/{portId}/stats',
            path_params=_path_params,
            query_params=_query_params,
            header_params=_header_params,
            body=_body_params,
            post_params=_form_params,
            files=_files,
            auth_settings=_auth_settings,
            collection_formats=_collection_formats,
            _host=_host,
            _request_auth=_request_auth
        )





# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictStr, field_validator
from typing import Any, ClassVar, Dict, List, Optional
from typing_extensions import Annotated
from typing import Optional, Set
from typing_extensions import Self

class BgpConfigRequestInput(BaseModel):
    """
    BgpConfigRequestInput
    """ # noqa: E501
    asn: Annotated[int, Field(le=4294967295, strict=True, ge=0)] = Field(description="Autonomous System Number for local BGP deployment.")
    deployment_type: StrictStr = Field(description="Wether the BGP deployment is local or global. Local deployments are configured immediately. Global deployments will need to be reviewed by Equinix Metal engineers.")
    href: Optional[StrictStr] = None
    md5: Optional[Annotated[str, Field(strict=True)]] = Field(default=None, description="The plaintext password to share between BGP neighbors as an MD5 checksum: * must be 10-20 characters long * may not include punctuation * must be a combination of numbers and letters * must contain at least one lowercase, uppercase, and digit character ")
    use_case: Optional[StrictStr] = Field(default=None, description="A use case explanation (necessary for global BGP request review).")
    __properties: ClassVar[List[str]] = ["asn", "deployment_type", "href", "md5", "use_case"]

    @field_validator('deployment_type')
    def deployment_type_validate_enum(cls, value):
        """Validates the enum"""
        if value not in set(['local', 'global']):
            raise ValueError("must be one of enum values ('local', 'global')")
        return value

    @field_validator('md5')
    def md5_validate_regular_expression(cls, value):
        """Validates the regular expression"""
        if value is None:
            return value

        if not re.match(r"^(?=.*[a-z])(?=.*[A-Z])(?=.*\d)[a-zA-Z\d]{10,20}$", value):
            raise ValueError(r"must validate the regular expression /^(?=.*[a-z])(?=.*[A-Z])(?=.*\d)[a-zA-Z\d]{10,20}$/")
        return value

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of BgpConfigRequestInput from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of BgpConfigRequestInput from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "asn": obj.get("asn"),
            "deployment_type": obj.get("deployment_type"),
            "href": obj.get("href"),
            "md5": obj.get("md5"),
            "use_case": obj.get("use_case")
        })
        return _obj





# coding: utf-8

"""
    Equinix Fabric API v4

    Equinix Fabric is an advanced software-defined interconnection solution that enables you to directly, securely and dynamically connect to distributed infrastructure and digital ecosystems on platform Equinix via a single port, Customers can use Fabric to connect to: </br> 1. Cloud Service Providers - Clouds, network and other service providers.  </br> 2. Enterprises - Other Equinix customers, vendors and partners.  </br> 3. Myself - Another customer instance deployed at Equinix. </br> </br> <b>Integrations (SDKs, Tools) links:</b> </br> <a href=\"https://deploy.equinix.com/labs/fabric-java\\\">Fabric Java SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-go\\\">Fabric Go SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/equinix-sdk-python\\\">Fabric Python SDK</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-provider-equinix\\\">Equinix Terraform Provider</a> </br> <a href=\"https://deploy.equinix.com/labs/terraform-equinix-fabric\\\">Fabric Terraform Modules</a> </br> <a href=\"https://deploy.equinix.com/labs/pulumi-provider-equinix/\">Equinix Pulumi Provider</a> </br>

    The version of the OpenAPI document: 4.18
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictFloat, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional, Union
from equinix.services.fabricv4.models.changelog import Changelog
from equinix.services.fabricv4.models.link import Link
from equinix.services.fabricv4.models.network_operation import NetworkOperation
from equinix.services.fabricv4.models.network_scope import NetworkScope
from equinix.services.fabricv4.models.network_state import NetworkState
from equinix.services.fabricv4.models.network_type import NetworkType
from equinix.services.fabricv4.models.project import Project
from equinix.services.fabricv4.models.simplified_account import SimplifiedAccount
from equinix.services.fabricv4.models.simplified_location import SimplifiedLocation
from equinix.services.fabricv4.models.simplified_network_change import SimplifiedNetworkChange
from equinix.services.fabricv4.models.simplified_notification import SimplifiedNotification
from typing import Optional, Set
from typing_extensions import Self

class Network(BaseModel):
    """
    Network specification
    """ # noqa: E501
    type: NetworkType
    name: StrictStr = Field(description="Customer-provided network name")
    scope: NetworkScope
    location: Optional[SimplifiedLocation] = None
    project: Optional[Project] = None
    notifications: List[SimplifiedNotification] = Field(description="Preferences for notifications on network configuration or status changes")
    href: StrictStr = Field(description="Network URI")
    uuid: StrictStr = Field(description="Equinix-assigned network identifier")
    state: NetworkState
    connections_count: Optional[Union[StrictFloat, StrictInt]] = Field(default=None, description="number of connections created on the network", alias="connectionsCount")
    account: Optional[SimplifiedAccount] = None
    change: Optional[SimplifiedNetworkChange] = None
    operation: Optional[NetworkOperation] = None
    change_log: Changelog = Field(alias="changeLog")
    links: Optional[List[Link]] = Field(default=None, description="Network sub-resources links")
    additional_properties: Dict[str, Any] = {}
    __properties: ClassVar[List[str]] = ["type", "name", "scope", "location", "project", "notifications", "href", "uuid", "state", "connectionsCount", "account", "change", "operation", "changeLog", "links"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of Network from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        * OpenAPI `readOnly` fields are excluded.
        * OpenAPI `readOnly` fields are excluded.
        * Fields in `self.additional_properties` are added to the output dict.
        """
        excluded_fields: Set[str] = set([
            "href",
            "links",
            "additional_properties",
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # override the default output from pydantic by calling `to_dict()` of location
        if self.location:
            _dict['location'] = self.location.to_dict()
        # override the default output from pydantic by calling `to_dict()` of project
        if self.project:
            _dict['project'] = self.project.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in notifications (list)
        _items = []
        if self.notifications:
            for _item in self.notifications:
                if _item:
                    _items.append(_item.to_dict())
            _dict['notifications'] = _items
        # override the default output from pydantic by calling `to_dict()` of account
        if self.account:
            _dict['account'] = self.account.to_dict()
        # override the default output from pydantic by calling `to_dict()` of change
        if self.change:
            _dict['change'] = self.change.to_dict()
        # override the default output from pydantic by calling `to_dict()` of operation
        if self.operation:
            _dict['operation'] = self.operation.to_dict()
        # override the default output from pydantic by calling `to_dict()` of change_log
        if self.change_log:
            _dict['changeLog'] = self.change_log.to_dict()
        # override the default output from pydantic by calling `to_dict()` of each item in links (list)
        _items = []
        if self.links:
            for _item in self.links:
                if _item:
                    _items.append(_item.to_dict())
            _dict['links'] = _items
        # puts key-value pairs in additional_properties in the top level
        if self.additional_properties is not None:
            for _key, _value in self.additional_properties.items():
                _dict[_key] = _value

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of Network from a dict"""
        if obj is None:
            return None

        if not isinstance(obj, dict):
            return cls.model_validate(obj)

        _obj = cls.model_validate({
            "type": obj.get("type"),
            "name": obj.get("name"),
            "scope": obj.get("scope"),
            "location": SimplifiedLocation.from_dict(obj["location"]) if obj.get("location") is not None else None,
            "project": Project.from_dict(obj["project"]) if obj.get("project") is not None else None,
            "notifications": [SimplifiedNotification.from_dict(_item) for _item in obj["notifications"]] if obj.get("notifications") is not None else None,
            "href": obj.get("href"),
            "uuid": obj.get("uuid"),
            "state": obj.get("state"),
            "connectionsCount": obj.get("connectionsCount"),
            "account": SimplifiedAccount.from_dict(obj["account"]) if obj.get("account") is not None else None,
            "change": SimplifiedNetworkChange.from_dict(obj["change"]) if obj.get("change") is not None else None,
            "operation": NetworkOperation.from_dict(obj["operation"]) if obj.get("operation") is not None else None,
            "changeLog": Changelog.from_dict(obj["changeLog"]) if obj.get("changeLog") is not None else None,
            "links": [Link.from_dict(_item) for _item in obj["links"]] if obj.get("links") is not None else None
        })
        # store additional fields in additional_properties
        for _key in obj.keys():
            if _key not in cls.__properties:
                _obj.additional_properties[_key] = obj.get(_key)

        return _obj





# coding: utf-8

"""
    Metal API

    The version of the OpenAPI document: 1.0.0
    Contact: support@equinixmetal.com
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from equinix.services.metalv1.models.instances_batch_create_input_batches_inner import InstancesBatchCreateInputBatchesInner

class TestInstancesBatchCreateInputBatchesInner(unittest.TestCase):
    """InstancesBatchCreateInputBatchesInner unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> InstancesBatchCreateInputBatchesInner:
        """Test InstancesBatchCreateInputBatchesInner
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `InstancesBatchCreateInputBatchesInner`
        """
        model = InstancesBatchCreateInputBatchesInner()
        if include_optional:
            return InstancesBatchCreateInputBatchesInner(
                hostnames = [
                    ''
                    ],
                quantity = 56,
                href = '',
                metro = 'sv',
                always_pxe = True,
                billing_cycle = 'hourly',
                customdata = { },
                description = '',
                features = [
                    ''
                    ],
                hardware_reservation_id = 'next-available',
                hostname = '',
                ip_addresses = [
                    equinix.services.metalv1.models.ip_address.IPAddress(
                        address_family = 4, 
                        cidr = 28, 
                        href = '', 
                        ip_reservations = [
                            ''
                            ], 
                        public = False, )
                    ],
                ipxe_script_url = '',
                locked = True,
                network_frozen = True,
                no_ssh_keys = True,
                operating_system = '',
                plan = 'c3.large.x86',
                private_ipv4_subnet_size = 56,
                project_ssh_keys = [
                    ''
                    ],
                public_ipv4_subnet_size = 56,
                spot_instance = True,
                spot_price_max = 1.23,
                ssh_keys = [
                    equinix.services.metalv1.models.ssh_key_input.SSHKeyInput(
                        href = '', 
                        key = '', 
                        label = '', 
                        tags = [
                            ''
                            ], )
                    ],
                storage = equinix.services.metalv1.models.storage.Storage(
                    disks = [
                        equinix.services.metalv1.models.disk.Disk(
                            device = '', 
                            href = '', 
                            partitions = [
                                equinix.services.metalv1.models.partition.Partition(
                                    href = '', 
                                    label = '', 
                                    number = 56, 
                                    size = '', )
                                ], 
                            wipe_table = True, )
                        ], 
                    filesystems = [
                        equinix.services.metalv1.models.filesystem.Filesystem(
                            href = '', 
                            mount = equinix.services.metalv1.models.mount.Mount(
                                device = '', 
                                format = '', 
                                href = '', 
                                options = [
                                    ''
                                    ], 
                                point = '', ), )
                        ], 
                    href = '', 
                    raid = [
                        equinix.services.metalv1.models.raid.Raid(
                            devices = [
                                ''
                                ], 
                            href = '', 
                            level = '', 
                            name = '', )
                        ], ),
                tags = [
                    ''
                    ],
                termination_time = datetime.datetime.strptime('2013-10-20 19:20:30.00', '%Y-%m-%d %H:%M:%S.%f'),
                user_ssh_keys = [
                    ''
                    ],
                userdata = '',
                facility = None
            )
        else:
            return InstancesBatchCreateInputBatchesInner(
                metro = 'sv',
                operating_system = '',
                plan = 'c3.large.x86',
                facility = None,
        )
        """

    def testInstancesBatchCreateInputBatchesInner(self):
        """Test InstancesBatchCreateInputBatchesInner"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()



# flake8: noqa

# import apis into api package
from equinix.services.fabricv4.api.cloud_routers_api import CloudRoutersApi
from equinix.services.fabricv4.api.connections_api import ConnectionsApi
from equinix.services.fabricv4.api.health_api import HealthApi
from equinix.services.fabricv4.api.marketplace_subscriptions_api import MarketplaceSubscriptionsApi
from equinix.services.fabricv4.api.metros_api import MetrosApi
from equinix.services.fabricv4.api.networks_api import NetworksApi
from equinix.services.fabricv4.api.ports_api import PortsApi
from equinix.services.fabricv4.api.precision_time_api import PrecisionTimeApi
from equinix.services.fabricv4.api.prices_api import PricesApi
from equinix.services.fabricv4.api.route_aggregation_rules_api import RouteAggregationRulesApi
from equinix.services.fabricv4.api.route_aggregations_api import RouteAggregationsApi
from equinix.services.fabricv4.api.route_filter_rules_api import RouteFilterRulesApi
from equinix.services.fabricv4.api.route_filters_api import RouteFiltersApi
from equinix.services.fabricv4.api.routing_protocols_api import RoutingProtocolsApi
from equinix.services.fabricv4.api.service_profiles_api import ServiceProfilesApi
from equinix.services.fabricv4.api.service_tokens_api import ServiceTokensApi
from equinix.services.fabricv4.api.statistics_api import StatisticsApi
from equinix.services.fabricv4.api.stream_subscriptions_api import StreamSubscriptionsApi
from equinix.services.fabricv4.api.streams_api import StreamsApi




# coding: utf-8

from setuptools import setup, find_packages  # noqa: H301

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools
NAME = "equinix"
VERSION = open('version').read()
PYTHON_REQUIRES = ">=3.7"
REQUIRES = [
    "urllib3 >=2.2.2, <3.0.0",
    "python-dateutil",
    "pydantic >= 2",
    "typing-extensions >= 4.7.1",
]

setup(
    name=NAME,
    version=VERSION,
    description="Equinix SDK for Python",
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author="Equinix",
    url="https://github.com/equinix/equinix-sdk-python",
    keywords=["Equinix"],
    install_requires=REQUIRES,
    python_requires=PYTHON_REQUIRES,
    packages=find_packages(exclude=["test", "tests"]),
    include_package_data=True,
    license="MIT",
    package_data={"equinix.services.metalv1": ["py.typed"]},
)
